[tor-commits] [stem/master] OR_CONN_CLOSED changed to CHANNEL_CLOSED

atagar at torproject.org atagar at torproject.org
Fri Aug 21 01:23:42 UTC 2020


commit 12bf19f59f08ad2aba95cb53b42da21aa0c73a33
Author: Damian Johnson <atagar at torproject.org>
Date:   Thu Aug 20 18:00:55 2020 -0700

    OR_CONN_CLOSED changed to CHANNEL_CLOSED
    
    This value's description didn't change, just its name.
    
      https://gitweb.torproject.org/torspec.git/commit/?id=693f5d4
---
 stem/client/datatype.py | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/stem/client/datatype.py b/stem/client/datatype.py
index 527fdb12..701f588b 100644
--- a/stem/client/datatype.py
+++ b/stem/client/datatype.py
@@ -115,6 +115,9 @@ users.** See our :class:`~stem.client.Relay` the API you probably want.
 
   Reason a relay is closed.
 
+  .. versionchanged:: 2.0.0
+     OR_CONN_CLOSED changed to CHANNEL_CLOSED (:spec:`693f5d4`)
+
   ===================== ===========
   CloseReason           Description
   ===================== ===========
@@ -126,7 +129,7 @@ users.** See our :class:`~stem.client.Relay` the API you probably want.
   **RESOURCELIMIT**     out of memory, sockets, or circuit IDs
   **CONNECTFAILED**     unable to reach relay
   **OR_IDENTITY**       connected, but its OR identity was not as expected
   **OR_CONN_CLOSED**    connection that was carrying this circuit died
   **FINISHED**          circuit has expired for being dirty or old
   **TIMEOUT**           circuit construction took too long
   **DESTROYED**         circuit was destroyed without a client TRUNCATE
@@ -240,7 +243,7 @@ CloseReason = _IntegerEnum(
   ('RESOURCELIMIT', 5),
   ('CONNECTFAILED', 6),
   ('OR_IDENTITY', 7),
-  ('OR_CONN_CLOSED', 8),
+  ('CHANNEL_CLOSED', 8),
   ('FINISHED', 9),
   ('TIMEOUT', 10),
   ('DESTROYED', 11),
@@ -126,7 +129,7 @@ users.** See our :class:`~stem.client.Relay` the API you probably want.
   **CONNECTFAILED**     unable to reach relay
   **OR_IDENTITY**       connected, but its OR identity was not as expected
-  **OR_CONN_CLOSED**    connection that was carrying this circuit died
+  **CHANNEL_CLOSED**    connection that was carrying this circuit died
   **FINISHED**          circuit has expired for being dirty or old
   **TIMEOUT**           circuit construction took too long





More information about the tor-commits mailing list